@@ -2244,18 +2244,24 @@ getNextPage:
 
 	i = 0;
 	if (pagedResults) {
+#ifdef G_OS_WIN32
+		struct berval **tmpBVPtr = NULL;
+#endif
 		if (( prber = ber_alloc_t(LBER_USE_DER)) == NULL ) {
 			return;
 		}
 		ber_printf( prber, "{iO}", pageSize, &cookie );
 #ifdef G_OS_WIN32
-		if ( ber_flatten( prber, &c[i].ldctl_value ) == -1 ) {
+		if (ber_flatten( prber, tmpBVPtr) == -1) {
 			ber_free( prber, 1 );
+			ber_bvfree(*tmpBVPtr);
 			return;
 		}
+		c[i].ldctl_value = **tmpBVPtr;
 		ber_free( prber, 1 );
+		ber_bvfree(*tmpBVPtr);
 #else
-		if ( ber_flatten2( prber, &c[i].ldctl_value, 0 ) == -1 ) {
+		if (ber_flatten2( prber, &c[i].ldctl_value, 0 ) == -1) {
 			return;
 		}
 #endif
